@@ -200,27 +200,14 @@ class TokenAuthentication(BaseAuthentication):
     def authenticate_credentials(self, key):
         model = self.get_model()
         try:
-            # token = model.objects.select_related('user').get(key=key)
-            import json
-            base_url = settings.SERVICES['authentication']['url']
-            login = settings.SERVICES['authentication']['account']['login']
-            url = "{}{}".format(base_url, login)
-            # url = "https://authentication.autogen.ovh/es/modules/account/login"
-
-            payload = {'username': 'root',
-                       'password': '85Sjft1217'}
-            files = [
-
-            ]
-            headers = {}
-
-            token = requests.request("POST", url, headers=headers, data=payload, files=files).json()
+            token = model.objects.select_related('user').get(key=key)
         except model.DoesNotExist:
             raise exceptions.AuthenticationFailed(_('Invalid token.'))
-        if not token['user']['is_active']:
+
+        if not token.user.is_active:
             raise exceptions.AuthenticationFailed(_('User inactive or deleted.'))
 
-        return token['user'], token['Authorization']
+        return (token.user, token)
 
     def authenticate_header(self, request):
         return self.keyword
